@@ -12,53 +12,17 @@ set.seed(0)
 ###################################################
 ### code chunk number 2: niche_Synthsis_Method
 ###################################################
-# load the sdmvspecies library
 library("sdmvspecies")
-# find package's location
+library("raster")
 package.dir <- system.file(package="sdmvspecies")
-# let see where is our sdmvspecies is installed in
-package.dir
-# find env dir under the package's location
-env.dir <- paste(package.dir, "/external/env/", sep="")
-# let see env dir
-env.dir
-# get the environment raster file
-env.files <- list.files(env.dir, pattern="*.bil$", full.names=TRUE)
-# see the file list
-env.files
-# put the environment file in a raster stack, 
-# which require all the environment should have same resolution and extend
-env.stack <- stack(env.files)
-# let see the env.stack var
-env.stack
-# here let's configure the environment response function and weight
-config <- list(
-    c("bio1","1",2), 
-    c("bio14", "2", 2), 
-    c("bio5", "3", 1), 
-    c("bio11", "4", 2), 
-    c("bio16", "5", 1)
-    )
-# call the niche synthsis method
+env.dir <- paste(package.dir, "/external/env", sep="")
+files <- list.files(path=env.dir, pattern="*.bil$", full.names=TRUE)
+env.stack <- stack(files)
+print(files)
+config <- list(c("bio1","1",2), c("bio12", "2", 2), c("bio5", "3", 1), c("bio7", "4", 2))
 species.raster <- nicheSynthese(env.stack, config)
-# let see the result raster,
-# you should noticed that it's continue value map not distributin map
-species.raster
-
-# write the map to file, so you can use it latter in GIS software
-# or further analysis.
-# 
-#writeRaster(species.raster, "synthese.img", "HFA", overwrite=TRUE)
-
-# to make binary distribution map, you should chosee a threshold to make map
-# see the map then to decide the threshold to binary
-plot(species.raster)
-# choice threshold, here we choice 4
-threshold <- 14
-# make binary map
-distribution.map <- species.raster > threshold
-# plot the map out
-plot(distribution.map)
+species.raster <- rescale(species.raster)
+plot(species.raster>0.7)
 
 
 ###################################################
@@ -220,6 +184,7 @@ config <- list(
 ###################################################
 # load the sdmvspecies library
 library("sdmvspecies")
+library("raster")
 # find package's location
 package.dir <- system.file(package="sdmvspecies")
 # let see where is our sdmvspecies is installed in
@@ -293,30 +258,3 @@ species.distribution.raster <- species.raster > 0.2
 plot(species.distribution.raster)
 
 
-###################################################
-### code chunk number 12: artificial_bell_response_method
-###################################################
-# load the sdmvspecies library
-library("sdmvspecies")
-# find package's location
-package.dir <- system.file(package="sdmvspecies")
-# let see where is our sdmvspecies is installed in
-package.dir
-# find env dir under the package's location
-env.dir <- paste(package.dir, "/external/env/", sep="")
-# let see env dir
-env.dir
-# get the environment raster file
-file.name <- files <- c("bio1.bil", "bio11.bil")
-files <- paste(env.dir, file.name, sep="")
-# make raster stack
-env.stack <- stack(files)
-# config
-config <- list(c("bio1", "1", 0, 100), c("bio11", "2", -100, NULL))
-
-# run pick mean
-species.raster <- nicheLimitation(env.stack, config)
-# plot map
-plot(species.raster)
-
-
